@@ -21,9 +21,6 @@ class fotoradary:
         self.file = "./plugins/fotoradary.txt"
         self.ico_fotoradar = gdk.pixbuf_new_from_file("./plugins/fotoradary.png")
         self.f = []
-        self.f_images = []
-        self.box_old = 0,0,0,0
-        self.zoom_old = 0
 
         self.from_zoom = 13
 
@@ -31,27 +28,29 @@ class fotoradary:
 
 
     def f_rebuild(self):
-        box = self.osmMapa.osm.get_bbox()
-        t_lt, t_ln, b_lt, b_ln = box
-        if self.box_old <> box or self.zoom_old <> self.osmMapa.osm.props.zoom :
+        if self.from_zoom < self.osmMapa.osm.props.zoom :
+            t_lt, t_ln, b_lt, b_ln = self.osmMapa.osm.get_bbox()
             t_lt, t_ln, b_lt, b_ln = math.degrees(t_lt), math.degrees(t_ln), math.degrees(b_lt), math.degrees(b_ln)
 
-            self.clean_layer()
             for pa in self.f:
-
                 lt = float(pa[0])
                 ln = float(pa[1])
 
                 if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
-                    self.f_images.append( self.osmMapa.osm.image_add( lt, ln, self.ico_fotoradar ) )
+                    if not pa[3]:
+                        pa[3] = self.osmMapa.osm.image_add( lt, ln, self.ico_fotoradar )
+
+                else:
+                    if pa[3]:
+                        self.osmMapa.osm.image_remove(pa[3])
+                        pa[3] = None
 
-            self.box_old = box
-            self.zoom_old = self.osmMapa.osm.props.zoom
 
     def clean_layer(self):
-        for pr in self.f_images:
-            self.osmMapa.osm.image_remove(pr)
-        self.f_images = []
+        for pr in self.f:
+            if pr[3]:
+                self.osmMapa.osm.image_remove(pr[3])
+                pr[3] = None
 
     def killIt(self):
         self.clean_layer()
@@ -65,7 +64,7 @@ class fotoradary:
                 l = f.readline()
                 t = l.split(",")
                 if len(t) == 6 and t[0].find(".") != -1:
-                    self.f.append( [float(t[1]),float(t[0]),t[3]])
+                    self.f.append( [float(t[1]),float(t[0]),t[3],None])
             except:
                 pass
         print "fotoradary read poi xml found (",len(self.f),") POI :)"
