@@ -63,6 +63,12 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.18"
 """
+0.18-6
+    repo clean up
+    add repo UMP-PL http://ump.waw.pl/
+    plugin[fotoradary] clean up
+0.18-5
+    clean up package
 0.18-4
     add donate and about
     speed up what I can less redraw
@@ -199,7 +205,7 @@ timing_osd = 0
 maps_source = [
     [osmgpsmap.SOURCE_OPENSTREETMAP, "OpenStreetMap I"],
     [osmgpsmap.SOURCE_OPENSTREETMAP_RENDERER, "OpenStreetMap II"],
-    [osmgpsmap.SOURCE_OPENAERIALMAP, "OpenAerialMap"],
+#    [osmgpsmap.SOURCE_OPENAERIALMAP, "OpenAerialMap"],
 #    [osmgpsmap.SOURCE_OPENCYCLEMAP, "OpenCycleMap"],
 #    [osmgpsmap.SOURCE_OSM_PUBLIC_TRANSPORT, "Public Transport"],
 #    [osmgpsmap.SOURCE_OSMC_TRAILS, "OSMC Trails"],
@@ -210,9 +216,10 @@ maps_source = [
     [osmgpsmap.SOURCE_VIRTUAL_EARTH_STREET, "Virtual Earth"],
     [osmgpsmap.SOURCE_VIRTUAL_EARTH_SATELLITE, "Virtual Earth Satellite"],
     [osmgpsmap.SOURCE_VIRTUAL_EARTH_HYBRID, "Virtual Earth Hybrid"],
-    [osmgpsmap.SOURCE_YAHOO_STREET, "Yahoo Maps"],
-    [osmgpsmap.SOURCE_YAHOO_SATELLITE, "Yahoo Satellite"],
-    [osmgpsmap.SOURCE_YAHOO_HYBRID, "Yahoo Hybrid"]
+    ["http://tiles.ump.waw.pl/ump_tiles/#Z/#X/#Y.png", "UMP-PL" ]
+    #[osmgpsmap.SOURCE_YAHOO_STREET, "Yahoo Maps"],
+    #[osmgpsmap.SOURCE_YAHOO_SATELLITE, "Yahoo Satellite"],
+    #[osmgpsmap.SOURCE_YAHOO_HYBRID, "Yahoo Hybrid"]
                ]
 
 
@@ -263,6 +270,7 @@ class MyDialog( hildon.Dialog ):
     def on_map_source(self, widget, map_source):
         #def load_map_clicked(self, button=None, uri=None, format=None)
         CONFIG['engine_name'] = map_source
+
         self.osmMapa.load_map_clicked()
 
         self.on_close()
@@ -277,10 +285,17 @@ class MyDialog( hildon.Dialog ):
                 break
             else:
                 iter+=1
-        print "selected source map: ", maps_source[id]
-        CONFIG['engine_name'] = maps_source[id][0]
 
-        self.osmMapa.osm.props.map_source = maps_source[id][0]
+        if type( CONFIG['engine_name'] ) == int and type( maps_source[id][0] ) == int:
+            print "selected source map: ", maps_source[id]," using fash switch"
+            CONFIG['engine_name'] = maps_source[id][0]
+            self.osmMapa.osm.props.map_source = maps_source[id][0]
+
+        else:
+            print "selected source map: ", maps_source[id]," using long switch"
+            CONFIG['engine_name'] = maps_source[id][0]
+            self.osmMapa.load_map_clicked()
+
         self.on_close()
 
     def on_bt_rotate_click( self, w):
@@ -1024,9 +1039,14 @@ class UI(gtk.Window):
             pass
 
         try:
-            self.osm = osmgpsmap.GpsMap(
-                    map_source=CONFIG['engine_name']
-                    )
+            if type( CONFIG['engine_name'] ) == int:
+               self.osm = osmgpsmap.GpsMap(
+                            map_source=CONFIG['engine_name']
+                            )
+            else:
+                self.osm = osmgpsmap.GpsMap(
+                        repo_uri=CONFIG['engine_name']
+                        )
 
             self.osd = osmgpsmap.GpsMapOsd(show_crosshair=(not CONFIG['gpslock'] ))
             self.osm.layer_add(
